"use strict";

exports.__esModule = true;
exports.filterProps = filterProps;
exports.default = createAccessibilityStyledProps;

var _filterObjectProperties = require("../__modules__/filterObjectProperties");

var _styleSheet = _interopRequireDefault(require("../style-sheet"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Nicolas Gallagher.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
var hasOwnProperty = Object.prototype.hasOwnProperty;
var passList = {
  accessibilityActiveDescendant: true,
  accessibilityAtomic: true,
  accessibilityAutoComplete: true,
  accessibilityBusy: true,
  accessibilityChecked: true,
  accessibilityColumnCount: true,
  accessibilityColumnIndex: true,
  accessibilityColumnSpan: true,
  accessibilityControls: true,
  accessibilityDescribedBy: true,
  accessibilityDetails: true,
  accessibilityDisabled: true,
  accessibilityErrorMessage: true,
  accessibilityExpanded: true,
  accessibilityFlowTo: true,
  accessibilityHasPopup: true,
  accessibilityHidden: true,
  accessibilityInvalid: true,
  accessibilityKeyShortcuts: true,
  accessibilityLabel: true,
  accessibilityLabelledBy: true,
  accessibilityLevel: true,
  accessibilityLiveRegion: true,
  accessibilityModal: true,
  accessibilityMultiline: true,
  accessibilityMultiSelectable: true,
  accessibilityOrientation: true,
  accessibilityOwns: true,
  accessibilityPlaceholder: true,
  accessibilityPosInSet: true,
  accessibilityPressed: true,
  accessibilityReadOnly: true,
  accessibilityRequired: true,
  accessibilityRole: true,
  accessibilityRoleDescription: true,
  accessibilityRowCount: true,
  accessibilityRowIndex: true,
  accessibilityRowSpan: true,
  accessibilitySelected: true,
  accessibilitySetSize: true,
  accessibilitySort: true,
  accessibilityValueMax: true,
  accessibilityValueMin: true,
  accessibilityValueNow: true,
  accessibilityValueText: true,
  focusable: true,
  dataSet: true,
  nativeID: true,
  style: true,
  testID: true
};

function filterProps(props) {
  return (0, _filterObjectProperties.pick)(props, passList);
}

function excludeProps(props) {
  return (0, _filterObjectProperties.omit)(props, passList);
}

function createAccessibilityStyledProps(elementType, props) {
  if (props == null) {
    return {};
  }

  var accessibilityActiveDescendant = props.accessibilityActiveDescendant,
      accessibilityAtomic = props.accessibilityAtomic,
      accessibilityAutoComplete = props.accessibilityAutoComplete,
      accessibilityBusy = props.accessibilityBusy,
      accessibilityChecked = props.accessibilityChecked,
      accessibilityColumnCount = props.accessibilityColumnCount,
      accessibilityColumnIndex = props.accessibilityColumnIndex,
      accessibilityColumnSpan = props.accessibilityColumnSpan,
      accessibilityControls = props.accessibilityControls,
      accessibilityDescribedBy = props.accessibilityDescribedBy,
      accessibilityDetails = props.accessibilityDetails,
      accessibilityDisabled = props.accessibilityDisabled,
      accessibilityErrorMessage = props.accessibilityErrorMessage,
      accessibilityExpanded = props.accessibilityExpanded,
      accessibilityFlowTo = props.accessibilityFlowTo,
      accessibilityHasPopup = props.accessibilityHasPopup,
      accessibilityHidden = props.accessibilityHidden,
      accessibilityInvalid = props.accessibilityInvalid,
      accessibilityKeyShortcuts = props.accessibilityKeyShortcuts,
      accessibilityLabel = props.accessibilityLabel,
      accessibilityLabelledBy = props.accessibilityLabelledBy,
      accessibilityLevel = props.accessibilityLevel,
      accessibilityLiveRegion = props.accessibilityLiveRegion,
      accessibilityModal = props.accessibilityModal,
      accessibilityMultiline = props.accessibilityMultiline,
      accessibilityMultiSelectable = props.accessibilityMultiSelectable,
      accessibilityOrientation = props.accessibilityOrientation,
      accessibilityOwns = props.accessibilityOwns,
      accessibilityPlaceholder = props.accessibilityPlaceholder,
      accessibilityPosInSet = props.accessibilityPosInSet,
      accessibilityPressed = props.accessibilityPressed,
      accessibilityReadOnly = props.accessibilityReadOnly,
      accessibilityRequired = props.accessibilityRequired,
      accessibilityRole = props.accessibilityRole,
      accessibilityRoleDescription = props.accessibilityRoleDescription,
      accessibilityRowCount = props.accessibilityRowCount,
      accessibilityRowIndex = props.accessibilityRowIndex,
      accessibilityRowSpan = props.accessibilityRowSpan,
      accessibilitySelected = props.accessibilitySelected,
      accessibilitySetSize = props.accessibilitySetSize,
      accessibilitySort = props.accessibilitySort,
      accessibilityValueMax = props.accessibilityValueMax,
      accessibilityValueMin = props.accessibilityValueMin,
      accessibilityValueNow = props.accessibilityValueNow,
      accessibilityValueText = props.accessibilityValueText,
      classList = props.classList,
      focusable = props.focusable,
      dataSet = props.dataSet,
      nativeID = props.nativeID,
      style = props.style,
      testID = props.testID;
  var forwardedProps = excludeProps(props);
  delete forwardedProps.classList;

  if (accessibilityActiveDescendant != null) {
    forwardedProps['aria-activedescendant'] = accessibilityActiveDescendant;
  }

  if (accessibilityAtomic != null) {
    forwardedProps['aria-atomic'] = accessibilityAtomic;
  }

  if (accessibilityAutoComplete != null) {
    forwardedProps['aria-autocomplete'] = accessibilityAutoComplete;
  }

  if (accessibilityBusy != null) {
    forwardedProps['aria-busy'] = accessibilityBusy;
  }

  if (accessibilityChecked != null) {
    forwardedProps['aria-checked'] = accessibilityChecked;
  }

  if (accessibilityColumnCount != null) {
    forwardedProps['aria-colcount'] = accessibilityColumnCount;
  }

  if (accessibilityColumnIndex != null) {
    forwardedProps['aria-colindex'] = accessibilityColumnIndex;
  }

  if (accessibilityColumnSpan != null) {
    forwardedProps['aria-colspan'] = accessibilityColumnSpan;
  }

  if (accessibilityControls != null) {
    forwardedProps['aria-controls'] = accessibilityControls;
  }

  if (accessibilityDescribedBy != null) {
    forwardedProps['aria-describedby'] = accessibilityDescribedBy;
  }

  if (accessibilityDetails != null) {
    forwardedProps['aria-details'] = accessibilityDetails;
  }

  if (accessibilityDisabled === true) {
    forwardedProps['aria-disabled'] = true; // Enhance with native semantics

    if (elementType === 'button' || elementType === 'form' || elementType === 'input' || elementType === 'select' || elementType === 'textarea') {
      forwardedProps.disabled = true;
    }
  }

  if (accessibilityErrorMessage != null) {
    forwardedProps['aria-errormessage'] = accessibilityErrorMessage;
  }

  if (accessibilityExpanded != null) {
    forwardedProps['aria-expanded'] = accessibilityExpanded;
  }

  if (accessibilityFlowTo != null) {
    forwardedProps['aria-flowto'] = accessibilityFlowTo;
  }

  if (accessibilityHasPopup != null) {
    forwardedProps['aria-haspopup'] = accessibilityHasPopup;
  }

  if (accessibilityHidden === true) {
    forwardedProps['aria-hidden'] = accessibilityHidden;
  }

  if (accessibilityInvalid != null) {
    forwardedProps['aria-invalid'] = accessibilityInvalid;
  }

  if (accessibilityKeyShortcuts != null && Array.isArray(accessibilityKeyShortcuts)) {
    forwardedProps['aria-keyshortcuts'] = accessibilityKeyShortcuts.join(' ');
  }

  if (accessibilityLabel != null) {
    forwardedProps['aria-label'] = accessibilityLabel;
  }

  if (accessibilityLabelledBy != null) {
    forwardedProps['aria-labelledby'] = accessibilityLabelledBy;
  }

  if (accessibilityLevel != null) {
    forwardedProps['aria-level'] = accessibilityLevel;
  }

  if (accessibilityLiveRegion != null) {
    forwardedProps['aria-live'] = accessibilityLiveRegion;
  }

  if (accessibilityModal != null) {
    forwardedProps['aria-modal'] = accessibilityModal;
  }

  if (accessibilityMultiline != null) {
    forwardedProps['aria-multiline'] = accessibilityMultiline;
  }

  if (accessibilityMultiSelectable != null) {
    forwardedProps['aria-multiselectable'] = accessibilityMultiSelectable;
  }

  if (accessibilityOrientation != null) {
    forwardedProps['aria-orientation'] = accessibilityOrientation;
  }

  if (accessibilityOwns != null) {
    forwardedProps['aria-owns'] = accessibilityOwns;
  }

  if (accessibilityPlaceholder != null) {
    forwardedProps['aria-placeholder'] = accessibilityPlaceholder;
  }

  if (accessibilityPosInSet != null) {
    forwardedProps['aria-posinset'] = accessibilityPosInSet;
  }

  if (accessibilityPressed != null) {
    forwardedProps['aria-pressed'] = accessibilityPressed;
  }

  if (accessibilityReadOnly != null) {
    forwardedProps['aria-readonly'] = accessibilityReadOnly; // Enhance with native semantics

    if (elementType === 'input' || elementType === 'select' || elementType === 'textarea') {
      forwardedProps.readOnly = true;
    }
  }

  if (accessibilityRequired != null) {
    forwardedProps['aria-required'] = accessibilityRequired; // Enhance with native semantics

    if (elementType === 'input' || elementType === 'select' || elementType === 'textarea') {
      forwardedProps.required = true;
    }
  }

  if (accessibilityRole != null) {
    // 'presentation' synonym has wider browser support
    var role = accessibilityRole === 'none' ? 'presentation' : accessibilityRole;
    forwardedProps['role'] = role;
  }

  if (accessibilityRoleDescription != null) {
    forwardedProps['aria-roledescription'] = accessibilityRoleDescription;
  }

  if (accessibilityRowCount != null) {
    forwardedProps['aria-rowcount'] = accessibilityRowCount;
  }

  if (accessibilityRowIndex != null) {
    forwardedProps['aria-rowindex'] = accessibilityRowIndex;
  }

  if (accessibilityRowSpan != null) {
    forwardedProps['aria-rowspan'] = accessibilityRowSpan;
  }

  if (accessibilitySelected != null) {
    forwardedProps['aria-selected'] = accessibilitySelected;
  }

  if (accessibilitySetSize != null) {
    forwardedProps['aria-setsize'] = accessibilitySetSize;
  }

  if (accessibilitySort != null) {
    forwardedProps['aria-sort'] = accessibilitySort;
  }

  if (accessibilityValueMax != null) {
    forwardedProps['aria-valuemax'] = accessibilityValueMax;
  }

  if (accessibilityValueMin != null) {
    forwardedProps['aria-valuemin'] = accessibilityValueMin;
  }

  if (accessibilityValueNow != null) {
    forwardedProps['aria-valuenow'] = accessibilityValueNow;
  }

  if (accessibilityValueText != null) {
    forwardedProps['aria-valuetext'] = accessibilityValueText;
  } // "dataSet" replaced with "data-*"


  if (dataSet != null) {
    for (var dataProp in dataSet) {
      if (hasOwnProperty.call(dataSet, dataProp)) {
        var dataValue = dataSet[dataProp];

        if (dataValue != null) {
          forwardedProps["data-" + dataProp] = dataValue;
        }
      }
    }
  } // "focusable" indicates that an element is a keyboard tab-stop.


  if (focusable != null) {
    if ( // These native elements are focusable by default
    elementType === 'a' || elementType === 'button' || elementType === 'input' || elementType === 'select' || elementType === 'textarea') {
      if (focusable === false || accessibilityDisabled === true) {
        forwardedProps.tabIndex = '-1';
      }
    } else if ( // These roles are made focusable by default
    accessibilityRole === 'button' || accessibilityRole === 'checkbox' || accessibilityRole === 'link' || accessibilityRole === 'radio' || accessibilityRole === 'textbox' || accessibilityRole === 'switch') {
      if (focusable !== false) {
        forwardedProps.tabIndex = '0';
      }
    } else {
      // Everything else must explicitly set the prop
      if (focusable === true) {
        forwardedProps.tabIndex = '0';
      }
    }
  } // "nativeID" replaced with "id"


  if (nativeID != null) {
    forwardedProps.id = nativeID;
  } // "testID" replaced with "data-testid"


  if (process.env.NODE_ENV !== 'production') {
    if (testID != null) {
      forwardedProps['data-testid'] = testID;
    }
  } // "classList" & "style" replaced with native "className" & "style"


  var resolvedStyleProps = _styleSheet.default.resolve(style, classList);

  var className = resolvedStyleProps.className;

  if (className != null && className !== '') {
    forwardedProps.className = className;
  }

  if (resolvedStyleProps.style) {
    forwardedProps.style = resolvedStyleProps.style;
  }

  return forwardedProps;
}