"use strict";

exports.__esModule = true;
exports.default = useEvent;

var _createEventHandle = _interopRequireDefault(require("../create-event-handle"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

var _useStable = _interopRequireDefault(require("../__modules__/useStable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */

/**
 * This can be used with any event type include custom events.
 *
 * const click = useEvent('click', options);
 * useEffect(() => {
 *   click.setListener(target, onClick);
 *   return () => click.clear();
 * }).
 */
function useEvent(event, options) {
  var handle = (0, _useStable.default)(function () {
    return (0, _createEventHandle.default)(event, options);
  });
  (0, _useLayoutEffect.default)(function () {
    return function () {
      if (handle !== null) {
        handle.clear();
        handle = null;
      }
    };
  }, [handle]);
  return handle;
}

module.exports = exports.default;