"use strict";

exports.__esModule = true;
exports.default = useFileSelector;

var React = _interopRequireWildcard(require("react"));

var _useLayoutEffect = _interopRequireDefault(require("../__modules__/useLayoutEffect"));

var _useStable = _interopRequireDefault(require("../__modules__/useStable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
function createInput() {
  var input = document.createElement('input');
  input.type = 'file';
  return input;
}

function clearInput(input) {
  input.value = '';
}

function processAcceptTypes(acceptTypes) {
  return acceptTypes.map(function (fileType) {
    if (fileType.indexOf('/') !== -1 || fileType[0] === '.') {
      return fileType;
    }

    console.error("useFileSelector: \"acceptType\" value of " + fileType + " is not a valid MIME type or file extension.", 'File extensions must start with a "." character.');
  }).join(',');
}

function useFileSelector(onFilesChange, options) {
  var acceptMultiple = options.acceptMultiple,
      acceptTypes = options.acceptTypes,
      source = options.source;
  var input = (0, _useStable.default)(createInput);
  var openFileSelector = React.useCallback(function () {
    return input.click();
  }, [input]);
  var onChange = React.useCallback(function (e) {
    e.preventDefault();

    if (e.target instanceof HTMLInputElement) {
      onFilesChange(Array.from(e.target.files));
      clearInput(input);
    }
  }, [input, onFilesChange]);
  (0, _useLayoutEffect.default)(function () {
    var accept = acceptTypes != null ? processAcceptTypes(acceptTypes) : null;

    if (accept != null) {
      input.setAttribute('accept', accept);
    }

    if (source != null) {
      input.setAttribute('capture', source);
    }

    if (acceptMultiple != null) {
      input.setAttribute('multiple', String(acceptMultiple));
    } // $FlowExpectedError: sigh


    input.addEventListener('change', onChange);
    return function () {
      // $FlowExpectedError: sigh
      input.removeEventListener('change', onChange);
    };
  }, [acceptMultiple, acceptTypes, source, onChange, input]);
  return openFileSelector;
}

module.exports = exports.default;