/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
'use strict';

exports.__esModule = true;
exports.default = usePan;

var React = _interopRequireWildcard(require("react"));

var _events = require("./events");

exports.usePanEvents = _events.usePanEvents;

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var emptyObject = {};

function usePan(targetRef, config) {
  var _ref = config || emptyObject,
      _onMoveShouldSetPan = _ref.onMoveShouldSetPan,
      _onMoveShouldSetPanCapture = _ref.onMoveShouldSetPanCapture,
      _onStartShouldSetPan = _ref.onStartShouldSetPan,
      _onStartShouldSetPanCapture = _ref.onStartShouldSetPanCapture,
      _onPanTerminationRequest = _ref.onPanTerminationRequest,
      touchAction = _ref.touchAction;

  var _React$useState = React.useState(false),
      isPanned = _React$useState[0],
      setIsPanned = _React$useState[1];

  var _React$useState2 = React.useState({}),
      gestureState = _React$useState2[0],
      setGestureState = _React$useState2[1];

  (0, _events.usePanEvents)(targetRef, {
    onMoveShouldSetPan: function onMoveShouldSetPan(e, gestureState) {
      setGestureState(gestureState);
      return _onMoveShouldSetPan != null ? _onMoveShouldSetPan(e, gestureState) : false;
    },
    onMoveShouldSetPanCapture: function onMoveShouldSetPanCapture(e, gestureState) {
      setGestureState(gestureState);
      return _onMoveShouldSetPanCapture != null ? _onMoveShouldSetPanCapture(e, gestureState) : false;
    },
    onStartShouldSetPan: function onStartShouldSetPan(e, gestureState) {
      setGestureState(gestureState);
      return _onStartShouldSetPan != null ? _onStartShouldSetPan(e, gestureState) : false;
    },
    onStartShouldSetPanCapture: function onStartShouldSetPanCapture(e, gestureState) {
      setGestureState(gestureState);
      return _onStartShouldSetPanCapture != null ? _onStartShouldSetPanCapture(e, gestureState) : false;
    },
    onPanGrant: function onPanGrant(e, gestureState) {
      setIsPanned(true);
      setGestureState(gestureState);
    },
    onPanReject: function onPanReject(e, gestureState) {
      setGestureState(gestureState);
    },
    onPanStart: function onPanStart(e, gestureState) {
      setGestureState(gestureState);
    },
    onPanMove: function onPanMove(e, gestureState) {
      setGestureState(gestureState);
    },
    onPanEnd: function onPanEnd(e, gestureState) {
      setGestureState(gestureState);
    },
    onPanRelease: function onPanRelease(e, gestureState) {
      setIsPanned(false);
      setGestureState(gestureState);
    },
    onPanTerminate: function onPanTerminate(e, gestureState) {
      setIsPanned(false);
      setGestureState(gestureState);
    },
    onPanTerminationRequest: function onPanTerminationRequest(e, gestureState) {
      setGestureState(gestureState);
      return _onPanTerminationRequest != null ? _onPanTerminationRequest(e, gestureState) : true;
    },
    touchAction: touchAction
  });
  return {
    isPanned: isPanned,
    gestureState: gestureState
  };
}