/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * 
 */
'use strict';

exports.__esModule = true;
exports.default = usePress;

var React = _interopRequireWildcard(require("react"));

var _events = require("./events");

exports.usePressEvents = _events.usePressEvents;

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var emptyObject = {};

function usePress(targetRef, config) {
  var _ref = config || emptyObject,
      disabled = _ref.disabled,
      _onLongPress = _ref.onLongPress,
      onPress = _ref.onPress,
      touchAction = _ref.touchAction;

  var _React$useState = React.useState(false),
      isPressed = _React$useState[0],
      setPressed = _React$useState[1];

  var _React$useState2 = React.useState(false),
      isLongPressed = _React$useState2[0],
      setLongPressed = _React$useState2[1];

  (0, _events.usePressEvents)(targetRef, {
    disabled: disabled,
    onLongPress: function onLongPress() {
      if (_onLongPress != null) {
        setLongPressed(true);

        _onLongPress();
      }
    },
    onPress: onPress,
    onPressChange: function onPressChange(bool) {
      setPressed(bool);
    },
    onPressEnd: function onPressEnd() {
      if (_onLongPress != null) {
        setLongPressed(false);
      }
    },
    touchAction: touchAction
  });
  return {
    isPressed: isPressed,
    isLongPressed: isLongPressed
  };
}